.. python-anticaptcha documentation master file, created by
   sphinx-quickstart on Mon Feb 26 11:20:08 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to python-anticaptcha's documentation!
==============================================

.. include:: ../README.rst
  :start-after: introduction-start
  :end-before: introduction-end

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage
   fields
   api
   changes
   development

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
